==> gcloud-storage-utils-1.0.6-sources.jar: com/evolveasia/aws/AwsMetaInfo.kt <==
package com.evolveasia.aws

import android.content.Context
import android.graphics.Bitmap
import org.json.JSONObject
import kotlin.properties.Delegates

class AwsMetaInfo(var context: Context,
                  val bucketName: String,
                  var awsFolerPath: String,
                  val imageMetaInfo: ImageMetaInfo,
                  val serviceConfig: AWSConfig) {

    private constructor(builder: Builder) : this(context = builder.context, bucketName = builder.bucketName, awsFolerPath = builder.awsFolerPath, imageMetaInfo = builder.imageMetaInfo, serviceConfig = builder.serviceConfig)

    class Builder {
        var context: Context by Delegates.notNull()
        var bucketName: String by Delegates.notNull()
        var imageMetaInfo: ImageMetaInfo by Delegates.notNull()
        var awsFolerPath: String by Delegates.notNull()
        var serviceConfig: AWSConfig by Delegates.notNull()
        fun build() = AwsMetaInfo(this)
    }

    class ImageMetaInfo {
        var imagePath: String by Delegates.notNull()
        var mediaType: String by Delegates.notNull()
        var imageByteArray: ByteArray by Delegates.notNull()
        var metadata: String by Delegates.notNull()
        var compressLevel: Int = 100
        var compressFormat: Bitmap.CompressFormat = Bitmap.CompressFormat.PNG
        var imageWidth: Int? = null
        var imageHeight: Int? = null
        var waterMarkInfo: WaterMarkInfo? = null


        companion object {
            val TYPE_JPEG = "image/jpeg"
            val TYPE_PNG = "image/png"
        }
    }

    data class WaterMarkInfo(
            val waterMarkInfoList: List<Pair<String, String>>?
    ) {
        companion object {
            fun EMPTY(): WaterMarkInfo = WaterMarkInfo(emptyList())
        }
    }

    class AWSConfig(val awsConfiguration: JSONObject,
                    val bucketName: String,
                    val cognitoPoolId: String,
                    var region: String)

}

==> gcloud-storage-utils-1.0.7-sources.jar: com/evolveasia/aws/AwsMetaInfo.kt <==
package com.evolveasia.aws

import android.graphics.Bitmap
import org.json.JSONObject
import kotlin.properties.Delegates

class AwsMetaInfo(val bucketName: String,
                  var awsFolerPath: String,
                  val imageMetaInfo: ImageMetaInfo,
                  val serviceConfig: AWSConfig) {

    private constructor(builder: Builder) : this(bucketName = builder.bucketName, awsFolerPath = builder.awsFolerPath, imageMetaInfo = builder.imageMetaInfo, serviceConfig = builder.serviceConfig)

    class Builder {
        var bucketName: String by Delegates.notNull()
        var imageMetaInfo: ImageMetaInfo by Delegates.notNull()
        var awsFolerPath: String by Delegates.notNull()
        var serviceConfig: AWSConfig by Delegates.notNull()
        fun build() = AwsMetaInfo(this)
    }

    class ImageMetaInfo {
        var imagePath: String by Delegates.notNull()
        var mediaType: String by Delegates.notNull()
        var imageByteArray: ByteArray by Delegates.notNull()
        var metadata: String by Delegates.notNull()
        var compressLevel: Int = 100
        var compressFormat: Bitmap.CompressFormat = Bitmap.CompressFormat.PNG
        var imageWidth: Int? = null
        var imageHeight: Int? = null
        var waterMarkInfo: WaterMarkInfo? = null


        companion object {
            val TYPE_JPEG = "image/jpeg"
            val TYPE_PNG = "image/png"
        }
    }

    data class WaterMarkInfo(
            val waterMarkInfoList: List<Pair<String, String>>?
    ) {
        companion object {
            fun EMPTY(): WaterMarkInfo = WaterMarkInfo(emptyList())
        }
    }

    class AWSConfig(val awsConfiguration: JSONObject,
                    val bucketName: String,
                    val cognitoPoolId: String,
                    var region: String)

}
